==> odoo_19.0.20260216.zip: odoo-19.0.post20260216/odoo/addons/pos_event/static/tests/unit/data/event_event.data.js <==
import { patch } from "@web/core/utils/patch";
import { hootPosModels } from "@point_of_sale/../tests/unit/data/generate_model_definitions";
import { models } from "@web/../tests/web_test_helpers";

export class EventEvent extends models.ServerModel {
    _name = "event.event";

    _load_pos_data_fields() {
        return [
            "id",
            "name",
            "seats_available",
            "event_ticket_ids",
            "registration_ids",
            "seats_limited",
            "write_date",
            "question_ids",
            "general_question_ids",
            "specific_question_ids",
            "badge_format",
            "seats_max",
            "is_multi_slots",
            "event_slot_ids",
        ];
    }

    _records = [
        {
            id: 1,
            name: "Odoo Community Days",
            seats_available: 10,
            event_ticket_ids: [1],
            registration_ids: [],
            seats_limited: true,
            write_date: "2019-03-10 11:00:00",
            question_ids: [1, 2, 3, 4],
            general_question_ids: [],
            specific_question_ids: [],
            badge_format: "A6",
            seats_max: 10,
            is_multi_slots: true,
            event_slot_ids: [1],
        },
        {
            id: 2,
            name: "Unlimited Event",
            seats_available: 0,
            event_ticket_ids: [2],
            registration_ids: [],
            seats_limited: false,
            write_date: "2019-03-10 11:00:00",
            question_ids: [],
            general_question_ids: [],
            specific_question_ids: [],
            badge_format: "A6",
            seats_max: 0,
            is_multi_slots: false,
            event_slot_ids: [],
        },
        {
            id: 3,
            name: "Limited Event with Unlimited Ticket",
            seats_available: 5,
            event_ticket_ids: [2],
            registration_ids: [],
            seats_limited: true,
            write_date: "2019-03-10 11:00:00",
            question_ids: [],
            general_question_ids: [],
            specific_question_ids: [],
            badge_format: "A6",
            seats_max: 10,
            is_multi_slots: false,
            event_slot_ids: [],
        },
        {
            id: 4,
            name: "Sold Out Event with Unlimited Ticket",
            seats_available: 0,
            event_ticket_ids: [2],
            registration_ids: [],
            seats_limited: true,
            write_date: "2019-03-10 11:00:00",
            question_ids: [],
            general_question_ids: [],
            specific_question_ids: [],
            badge_format: "A6",
            seats_max: 10,
            is_multi_slots: false,
            event_slot_ids: [],
        },
        {
            id: 5,
            name: "Normal Event",
            seats_available: 8,
            event_ticket_ids: [5],
            registration_ids: [],
            seats_limited: true,
            write_date: "2019-03-10 11:00:00",
            question_ids: [],
            general_question_ids: [],
            specific_question_ids: [],
            badge_format: "A6",
            seats_max: 10,
            is_multi_slots: false,
            event_slot_ids: [],
        },
    ];

    get_slot_tickets_availability_pos(self, slot_ticket_ids) {
        return [5];
    }
}

patch(hootPosModels, [...hootPosModels, EventEvent]);

==> odoo_19.2a1.20260215.zip: odoo-19.2a1.post20260215/odoo/addons/pos_event/static/tests/unit/data/event_event.data.js <==
import { patch } from "@web/core/utils/patch";
import { hootPosModels } from "@point_of_sale/../tests/unit/data/generate_model_definitions";
import { models } from "@web/../tests/web_test_helpers";

export class EventEvent extends models.ServerModel {
    _name = "event.event";

    _load_pos_data_fields() {
        return [
            "id",
            "name",
            "seats_available",
            "event_ticket_ids",
            "registration_ids",
            "seats_limited",
            "write_date",
            "question_ids",
            "general_question_ids",
            "specific_question_ids",
            "badge_format",
            "seats_max",
            "is_multi_slots",
            "event_slot_ids",
        ];
    }

    _records = [
        {
            id: 1,
            name: "Odoo Community Days",
            seats_available: 10,
            event_ticket_ids: [1],
            registration_ids: [],
            seats_limited: true,
            write_date: "2019-03-10 11:00:00",
            question_ids: [1, 2, 3, 4, 5],
            general_question_ids: [],
            specific_question_ids: [],
            badge_format: "A6",
            seats_max: 10,
            is_multi_slots: true,
            event_slot_ids: [1],
        },
        {
            id: 2,
            name: "Unlimited Event",
            seats_available: 0,
            event_ticket_ids: [2],
            registration_ids: [],
            seats_limited: false,
            write_date: "2019-03-10 11:00:00",
            question_ids: [],
            general_question_ids: [],
            specific_question_ids: [],
            badge_format: "A6",
            seats_max: 0,
            is_multi_slots: false,
            event_slot_ids: [],
        },
        {
            id: 3,
            name: "Limited Event with Unlimited Ticket",
            seats_available: 5,
            event_ticket_ids: [2],
            registration_ids: [],
            seats_limited: true,
            write_date: "2019-03-10 11:00:00",
            question_ids: [],
            general_question_ids: [],
            specific_question_ids: [],
            badge_format: "A6",
            seats_max: 10,
            is_multi_slots: false,
            event_slot_ids: [],
        },
        {
            id: 4,
            name: "Sold Out Event with Unlimited Ticket",
            seats_available: 0,
            event_ticket_ids: [2],
            registration_ids: [],
            seats_limited: true,
            write_date: "2019-03-10 11:00:00",
            question_ids: [],
            general_question_ids: [],
            specific_question_ids: [],
            badge_format: "A6",
            seats_max: 10,
            is_multi_slots: false,
            event_slot_ids: [],
        },
        {
            id: 5,
            name: "Normal Event",
            seats_available: 8,
            event_ticket_ids: [5],
            registration_ids: [],
            seats_limited: true,
            write_date: "2019-03-10 11:00:00",
            question_ids: [],
            general_question_ids: [],
            specific_question_ids: [],
            badge_format: "A6",
            seats_max: 10,
            is_multi_slots: false,
            event_slot_ids: [],
        },
    ];

    get_slot_tickets_availability_pos(self, slot_ticket_ids) {
        return [5];
    }
}

patch(hootPosModels, [...hootPosModels, EventEvent]);
